@@ -11,6 +11,10 @@ def release(name, additional_args):
     utils.echo_info("building started...")
     projectConfig = get_config()
 
+    if not os.popen("pyenv versions").read():
+        echo_error(f"pyenv not found!")
+        return
+
     if name not in projectConfig:
         echo_error(f"{name} is not a valid config name.")
         return
@@ -30,11 +34,21 @@ def release(name, additional_args):
     if conf.get("flare"):
         if "debug" in additional_args:
             flare_build_type = "debug"
+            flare_build_env = ""
         else:
             flare_build_type = "release"
+            flare_build_env = "pyenv exec"
+
+            #enforce python 3.9.5
+            if "3.9.5" not in os.popen("pyenv versions").read():
+                os.system(f'pyenv install 3.9.5')
+            os.system("pyenv local 3.9.5")
 
         for name,flare in conf["flare"].items():
-            os.system(f'viur flare {flare_build_type} {name}')
+            os.system(f'{flare_build_env} viur flare {flare_build_type} {name}')
+
+        if flare_build_type == "release":
+            os.system("pyenv local system")
 
     #build all other apps and assets
     os.system('viur npm')
